@@ -27,7 +27,7 @@ pd.set_option('display.max_rows', 100)
 ## COMMAND LINE INTERFACE
 
 @click.group()
-@click.version_option("77.8.1", package_name="alacorder")
+@click.version_option("77.8.6", package_name="alacorder")
 def cli():
     """
     ALACORDER beta 77.8
@@ -144,13 +144,15 @@ def table(input_path, output_path, count, table, overwrite, log, no_write, no_pr
 @click.option('--compress','-z', default=False, is_flag=True,
               help="Compress exported file (archives compress with or without flag)")
 @click.option('--overwrite', '-o', default=False, help="Overwrite existing files at output path", is_flag=True,show_default=False)
+@click.option('--append', '-a', default=False, help="Append to archive at output path", is_flag=True,show_default=False)
 @click.option('--no-log','-q','log', default=False, is_flag=True, help="Don't print logs or progress to console")
 @click.option('--no-write','-n', default=False, is_flag=True, help="Do not export to output path", hidden=True)
 @click.option('--no-prompt', default=False, is_flag=True, help="Skip user input / confirmation prompts")
 @click.option('--debug','-d', default=False, is_flag=True, help="Print extensive logs to console for developers")
 @click.option('--no-batch','-b', default=True, is_flag=True, help="Process all inputs as one batch")
+@click.option('--skip','-skip', default='', type=click.Path(), help="Skip paths in archive at provided skip path")
 @click.version_option(package_name='alacorder', prog_name='ALACORDER', message='%(prog)s beta %(version)s')
-def archive(input_path, output_path, count, overwrite, dedupe, log, no_write, no_batch, no_prompt, debug, compress):
+def archive(input_path, output_path, count, overwrite, append, dedupe, log, no_write, no_batch, no_prompt, debug, compress, skip):
 
     # show_options_menu = False
     table = ""
@@ -188,6 +190,25 @@ def archive(input_path, output_path, count, overwrite, dedupe, log, no_write, no
     if outputs.OUTPUT_EXT != ".xlsx" and outputs.OUTPUT_EXT != ".xls" and outputs.OUTPUT_EXT != ".dta" and outputs.OUTPUT_EXT != ".json" and outputs.OUTPUT_EXT != ".csv" and outputs.OUTPUT_EXT != ".zip" and outputs.OUTPUT_EXT != ".pkl" and outputs.OUTPUT_EXT != ".xz" and outputs.OUTPUT_EXT != ".parquet":
         raise Exception("Bad format!")
 
+    # skip paths in provided archive
+    if skip != "" and inputs.IS_FULL_TEXT == False:
+        try:
+            if log or debug:
+                click.secho(f"Collecting paths from archive at --skip path...",fg='yellow',italic=True)
+            skip_paths = alac.read(skip)
+            skip_paths = skip_paths['Path'].tolist()
+        except:
+            if debug:
+                click.echo("Key Error when reading --skip archive!")
+            pass
+        match_skip = pd.Series(inputs.QUEUE).map(lambda x: x not in skip_paths)
+        inputs.QUEUE = inputs.QUEUE[match_skip]
+        len_dif = inputs.FOUND - inputs.QUEUE.shape[0]
+        if len(skip_paths) > 0 and log or debug:
+                click.secho(f"Identified {len_dif} paths already in archive at path --skip.")
+    # append priority over overwrite
+    if append and overwrite:
+        overwrite = False
 
     # prompt overwrite
     if outputs.EXISTING_FILE and not overwrite:
@@ -199,7 +220,8 @@ def archive(input_path, output_path, count, overwrite, dedupe, log, no_write, no
             else:
                 raise Exception("Existing file at output path!")
 
-    cf = alac.set(inputs, outputs, count=count, table="", overwrite=overwrite, log=log, dedupe=dedupe, no_write=no_write, no_prompt=no_prompt, no_batch=no_batch, debug=debug, compress=compress)
+
+    cf = alac.set(inputs, outputs, count=count, table="", overwrite=overwrite, log=log, dedupe=dedupe, no_write=no_write, no_prompt=no_prompt, no_batch=no_batch, debug=debug, compress=compress, append=append)
 
     if debug:
         click.echo(cf)
@@ -338,7 +360,7 @@ def mark(in_path, out_path, no_write=False):
 
 @cli.command(help="Append one case text archive to another")
 @click.option("--input-path", "-in", "in_path", required=True, prompt="Path to archive / PDF directory", help="Path to input archive", type=click.Path())
-@click.option("--output-path", "-out", "out_path", required=True, prompt="Query template spreadsheet path", type=click.Path(), help="Path to output archive")
+@click.option("--output-path", "-out", "out_path", required=True, prompt="Path to output archive", type=click.Path(), help="Path to output archive")
 @click.option('--no-write','-n', default=False, is_flag=True, help="Do not export to output path", hidden=True)
 def append(in_path, out_path, no_write=False):
     input_archive = alac.read(in_path)
